@@ -99,8 +99,8 @@ def create_legacy_model_zip(
         license_file: The path to a license file to be included in the model.
     """
     # Append correct extension if necessary
-    if not output_path.lower().endswith(".czseg"):
-        output_path = output_path + ".czseg"
+    if not output_path.lower().endswith(".czmodel"):
+        output_path = output_path + ".czmodel"
 
     # Create ZIP file
     with ZipFile(output_path, mode="w") as zf:
